@@ -7,20 +7,23 @@ from fastapi.responses import JSONResponse
 from pydantic import BaseModel
 
 
-class MagicExceptionModel(BaseModel):
-    status_code: int = 452
-    message: str
-    json_response: dict = {}
-
-
 class MagicException(Exception):
     def __init__(self, message: str, json_response: dict = None):
         self.status_code: int = 452
         self.message: str = message
         self.json_response: dict = json_response or {}
 
-    def model(self) -> MagicExceptionModel:
-        return MagicExceptionModel(**self.__dict__)
+    class MagicExceptionModel(BaseModel):
+        status_code: int = 452
+        message: str
+        json_response: dict = {}
+
+    def to_model(self) -> MagicExceptionModel:
+        return self.MagicExceptionModel(**self.__dict__)
+
+    @classmethod
+    def get_model(cls) -> type(MagicExceptionModel):
+        return cls.MagicExceptionModel
 
 
 class BackendException(MagicException):
@@ -42,7 +45,7 @@ class TwilioException(MagicException):
 @g.app.exception_handler(MagicException)
 def backend_exception_handler(request: Request, exc: MagicException):
     print("EXC", exc.__dict__)
-    magic_exception_model = exc.model()
+    magic_exception_model = exc.to_model()
     return JSONResponse(
         status_code=magic_exception_model.status_code,
         content=magic_exception_model.dict(),
