@@ -1,11 +1,11 @@
 from twilio.rest import Client
 import os
 from functools import wraps
-# from magicapi import settings
 from magicapi import g
 
 from magicapi.Errors import TwilioException
 
+from twilio.base.exceptions import TwilioRestException
 
 try:
     client = Client(g.settings.twilio_account_sid, g.settings.twilio_auth_token)
@@ -43,16 +43,23 @@ def need_copilot_vars(f):
 
 @need_twilio_vars
 def send_text(to, body, from_number=FROM_NUMBER):
-    message = client.messages.create(body=body, from_=from_number, to=to,)
+    message = client.messages.create(
+        body=body,
+        from_=from_number,
+        to=to,
+    )
     return message.sid
 
 
 @need_twilio_vars
 def send_text_with_copilot(to, body, status_callback=g.settings.twilio_status_callback):
-    message = client.messages.create(
-        body=body,
-        messaging_service_sid=g.settings.twilio_messaging_service_sid,
-        to=to,
-        status_callback=status_callback,
-    )
-    return message.sid
+    try:
+        message = client.messages.create(
+            body=body,
+            messaging_service_sid=g.settings.twilio_messaging_service_sid,
+            to=to,
+            status_callback=status_callback,
+        )
+        return message.sid
+    except TwilioRestException as error:
+        print("Twilio error here", error)
